==> ejc-probuilddiary-api-3.0.0-20221008.094809-98-sources.jar: com/ejianc/business/probuilddiary/ledger/vo/LedgerVO.java <==
package com.ejianc.business.probuilddiary.ledger.vo;

import com.ejianc.framework.skeleton.refer.annotation.ReferDeserialTransfer;
import com.ejianc.framework.skeleton.refer.annotation.ReferSerialTransfer;
import com.ejianc.framework.skeleton.template.BaseVO;
import com.fasterxml.jackson.annotation.JsonFormat;

import java.util.ArrayList;
import java.util.Date;
import java.util.List;

/**
 * 日志台账
 * 
 * @author generator
 * 
 */
public class LedgerVO extends BaseVO {
    private static final long serialVersionUID = 1L;

    private Date effectiveDate; // 生效日期
    private String billCode; // 单据编号
    private String billName; // 单据名称
    private Integer billState; // 单据状态
    private String billStateName; // 单据状态名称
    private Long orgId; // 项目部id
    private String orgCode; // 项目部编码
    private String orgName; // 项目部名称
    private Long parentOrgId; // 项目部所属组织id
    private String parentOrgCode; // 项目部所属组织编码
    private String parentOrgName; // 项目部所属组织名称
    private Long projectId; // 项目id
    private String projectCode; // 项目编码
    private String projectName; // 项目名称
    private String sourceType; // 来源
    @JsonFormat(shape = JsonFormat.Shape.STRING, pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private Date fillDate; // 填报日期
    private String week; // 星期
    private String weather; // 天气
    private String windPower; // 风力
    private String temperature; // 温度
    private String humidity; // 湿度
    private Long airQuality; // 空气质量
    private String airQualityName; //空气质量名称
    private Long commitUserId; // 提交人id
    private String commitUserCode; // 提交人账号
    private String commitUserName; // 提交人名称
    @JsonFormat(shape = JsonFormat.Shape.STRING, pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private Date commitDate; // 提交日期
    private Long projectLogId; // 项目日志id

    private String provinceName; //省
    private String cityName; //市
    private String districtName; //区

    private List<LedgerDetailVO> ledgerDetailList = new ArrayList<>(); // 日志台账-施工内容（施工员）
    private List<LedgerScheduleVO> ledgerScheduleList = new ArrayList<>(); // 日志台账-进度情况（施工员）
    private List<LedgerTypeVO> ledgerTypeList = new ArrayList<>(); // 日志台账-施工组织设计、方案、交底、变更情况（技术负责人）
    private List<LedgerQualityVO> ledgerQualityList = new ArrayList<>(); // 日志台账-工程质量检查、验收情况（质检员）
    private List<LedgerSafetyVO> ledgerSafetyList = new ArrayList<>(); // 日志台账-安全活动情况（安全员）
    private List<LedgerMaterialVO> ledgerMaterialList = new ArrayList<>(); // 日志台账-材料进场情况（材料员）
    private List<LedgerEquipmentVO> ledgerEquipmentList = new ArrayList<>(); // 日志台账-设备进场情况（设备管理员）
    private List<LedgerExamineVO> ledgerExamineList = new ArrayList<>(); // 日志台账-原材料检验、时间、试块及见证取样送检等情况（取样员）
    private List<LedgerInformationVO> ledgerInformationList = new ArrayList<>(); // 日志台账-工程资料归档及会议情况（资料员）
    private List<LedgerOtherVO> ledgerOtherList = new ArrayList<>(); // 日志台账-其他情况

    private String ledgerScheduleDescription;
    private String ledgerTypeDescription;
    private String ledgerQualityDescription;
    private String ledgerSafetyDescription;
    private String ledgerMaterialDescription;
    private String ledgerEquipmentDescription;
    private String ledgerExamineDescription;
    private String ledgerInformationDescription;
    private String ledgerOtherDescription;

    public String getProvinceName() {
        return provinceName;
    }

    public void setProvinceName(String provinceName) {
        this.provinceName = provinceName;
    }

    public String getCityName() {
        return cityName;
    }

    public void setCityName(String cityName) {
        this.cityName = cityName;
    }

    public String getDistrictName() {
        return districtName;
    }

    public void setDistrictName(String districtName) {
        this.districtName = districtName;
    }

    public String getAirQualityName() {
        return airQualityName;
    }

    public void setAirQualityName(String airQualityName) {
        this.airQualityName = airQualityName;
    }

    public Date getEffectiveDate() {
        return effectiveDate;
    }

    public void setEffectiveDate(Date effectiveDate) {
        this.effectiveDate = effectiveDate;
    }
    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    public String getBillName() {
        return billName;
    }

    public void setBillName(String billName) {
        this.billName = billName;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    public String getBillStateName() {
        return billStateName;
    }

    public void setBillStateName(String billStateName) {
        this.billStateName = billStateName;
    }
    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getOrgCode() {
        return orgCode;
    }

    public void setOrgCode(String orgCode) {
        this.orgCode = orgCode;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    public Long getParentOrgId() {
        return parentOrgId;
    }

    public void setParentOrgId(Long parentOrgId) {
        this.parentOrgId = parentOrgId;
    }
    public String getParentOrgCode() {
        return parentOrgCode;
    }

    public void setParentOrgCode(String parentOrgCode) {
        this.parentOrgCode = parentOrgCode;
    }
    public String getParentOrgName() {
        return parentOrgName;
    }

    public void setParentOrgName(String parentOrgName) {
        this.parentOrgName = parentOrgName;
    }
    public Long getProjectId() {
        return projectId;
    }

    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }
    public String getProjectCode() {
        return projectCode;
    }

    public void setProjectCode(String projectCode) {
        this.projectCode = projectCode;
    }
    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }

    public String getSourceType() {
        return sourceType;
    }

    public void setSourceType(String sourceType) {
        this.sourceType = sourceType;
    }

    public Date getFillDate() {
        return fillDate;
    }

    public void setFillDate(Date fillDate) {
        this.fillDate = fillDate;
    }
    public String getWeek() {
        return week;
    }

    public void setWeek(String week) {
        this.week = week;
    }
    public String getWeather() {
        return weather;
    }

    public void setWeather(String weather) {
        this.weather = weather;
    }

    public String getWindPower() {
        return windPower;
    }

    public void setWindPower(String windPower) {
        this.windPower = windPower;
    }

    public String getTemperature() {
        return temperature;
    }

    public void setTemperature(String temperature) {
        this.temperature = temperature;
    }

    public String getHumidity() {
        return humidity;
    }

    public void setHumidity(String humidity) {
        this.humidity = humidity;
    }
    public Long getCommitUserId() {
        return commitUserId;
    }

    public void setCommitUserId(Long commitUserId) {
        this.commitUserId = commitUserId;
    }
    public String getCommitUserCode() {
        return commitUserCode;
    }

    public void setCommitUserCode(String commitUserCode) {
        this.commitUserCode = commitUserCode;
    }
    public String getCommitUserName() {
        return commitUserName;
    }

    public void setCommitUserName(String commitUserName) {
        this.commitUserName = commitUserName;
    }
    public Date getCommitDate() {
        return commitDate;
    }

    public void setCommitDate(Date commitDate) {
        this.commitDate = commitDate;
    }
    public Long getProjectLogId() {
        return projectLogId;
    }

    public void setProjectLogId(Long projectLogId) {
        this.projectLogId = projectLogId;
    }

     public List<LedgerDetailVO> getLedgerDetailList() {
        return ledgerDetailList;
     }

     public void setLedgerDetailList(List<LedgerDetailVO> ledgerDetailList) {
        this.ledgerDetailList = ledgerDetailList;
     }
     public List<LedgerScheduleVO> getLedgerScheduleList() {
        return ledgerScheduleList;
     }

     public void setLedgerScheduleList(List<LedgerScheduleVO> ledgerScheduleList) {
        this.ledgerScheduleList = ledgerScheduleList;
     }
     public List<LedgerTypeVO> getLedgerTypeList() {
        return ledgerTypeList;
     }

     public void setLedgerTypeList(List<LedgerTypeVO> ledgerTypeList) {
        this.ledgerTypeList = ledgerTypeList;
     }
     public List<LedgerQualityVO> getLedgerQualityList() {
        return ledgerQualityList;
     }

     public void setLedgerQualityList(List<LedgerQualityVO> ledgerQualityList) {
        this.ledgerQualityList = ledgerQualityList;
     }
     public List<LedgerSafetyVO> getLedgerSafetyList() {
        return ledgerSafetyList;
     }

     public void setLedgerSafetyList(List<LedgerSafetyVO> ledgerSafetyList) {
        this.ledgerSafetyList = ledgerSafetyList;
     }
     public List<LedgerMaterialVO> getLedgerMaterialList() {
        return ledgerMaterialList;
     }

     public void setLedgerMaterialList(List<LedgerMaterialVO> ledgerMaterialList) {
        this.ledgerMaterialList = ledgerMaterialList;
     }
     public List<LedgerEquipmentVO> getLedgerEquipmentList() {
        return ledgerEquipmentList;
     }

     public void setLedgerEquipmentList(List<LedgerEquipmentVO> ledgerEquipmentList) {
        this.ledgerEquipmentList = ledgerEquipmentList;
     }
     public List<LedgerExamineVO> getLedgerExamineList() {
        return ledgerExamineList;
     }

     public void setLedgerExamineList(List<LedgerExamineVO> ledgerExamineList) {
        this.ledgerExamineList = ledgerExamineList;
     }
     public List<LedgerInformationVO> getLedgerInformationList() {
        return ledgerInformationList;
     }

     public void setLedgerInformationList(List<LedgerInformationVO> ledgerInformationList) {
        this.ledgerInformationList = ledgerInformationList;
     }
     public List<LedgerOtherVO> getLedgerOtherList() {
        return ledgerOtherList;
     }

     public void setLedgerOtherList(List<LedgerOtherVO> ledgerOtherList) {
        this.ledgerOtherList = ledgerOtherList;
     }
    @ReferSerialTransfer(referCode="support-defdoc")
    public Long getAirQuality() {
        return airQuality;
    }

    @ReferDeserialTransfer
    public void setAirQuality(Long airQuality) {
        this.airQuality = airQuality;
    }


    public String getLedgerScheduleDescription() {
        return ledgerScheduleDescription;
    }

    public void setLedgerScheduleDescription(String ledgerScheduleDescription) {
        this.ledgerScheduleDescription = ledgerScheduleDescription;
    }

    public String getLedgerTypeDescription() {
        return ledgerTypeDescription;
    }

    public void setLedgerTypeDescription(String ledgerTypeDescription) {
        this.ledgerTypeDescription = ledgerTypeDescription;
    }

    public String getLedgerQualityDescription() {
        return ledgerQualityDescription;
    }

    public void setLedgerQualityDescription(String ledgerQualityDescription) {
        this.ledgerQualityDescription = ledgerQualityDescription;
    }

    public String getLedgerSafetyDescription() {
        return ledgerSafetyDescription;
    }

    public void setLedgerSafetyDescription(String ledgerSafetyDescription) {
        this.ledgerSafetyDescription = ledgerSafetyDescription;
    }

    public String getLedgerMaterialDescription() {
        return ledgerMaterialDescription;
    }

    public void setLedgerMaterialDescription(String ledgerMaterialDescription) {
        this.ledgerMaterialDescription = ledgerMaterialDescription;
    }

    public String getLedgerEquipmentDescription() {
        return ledgerEquipmentDescription;
    }

    public void setLedgerEquipmentDescription(String ledgerEquipmentDescription) {
        this.ledgerEquipmentDescription = ledgerEquipmentDescription;
    }

    public String getLedgerExamineDescription() {
        return ledgerExamineDescription;
    }

    public void setLedgerExamineDescription(String ledgerExamineDescription) {
        this.ledgerExamineDescription = ledgerExamineDescription;
    }

    public String getLedgerInformationDescription() {
        return ledgerInformationDescription;
    }

    public void setLedgerInformationDescription(String ledgerInformationDescription) {
        this.ledgerInformationDescription = ledgerInformationDescription;
    }

    public String getLedgerOtherDescription() {
        return ledgerOtherDescription;
    }

    public void setLedgerOtherDescription(String ledgerOtherDescription) {
        this.ledgerOtherDescription = ledgerOtherDescription;
    }
}

==> ejc-probuilddiary-api-3.0.0-20250327.054609-156-sources.jar: com/ejianc/business/probuilddiary/ledger/vo/LedgerVO.java <==
package com.ejianc.business.probuilddiary.ledger.vo;

import com.ejianc.framework.skeleton.refer.annotation.ReferDeserialTransfer;
import com.ejianc.framework.skeleton.refer.annotation.ReferSerialTransfer;
import com.ejianc.framework.skeleton.template.BaseVO;
import com.fasterxml.jackson.annotation.JsonFormat;

import java.util.ArrayList;
import java.util.Date;
import java.util.List;

/**
 * 日志台账
 * 
 * @author generator
 * 
 */
public class LedgerVO extends BaseVO {
    private static final long serialVersionUID = 1L;

    private Date effectiveDate; // 生效日期
    private String billCode; // 单据编号
    private String billName; // 单据名称
    private Integer billState; // 单据状态
    private String billStateName; // 单据状态名称
    private Long orgId; // 项目部id
    private String orgCode; // 项目部编码
    private String orgName; // 项目部名称
    private Long parentOrgId; // 项目部所属组织id
    private String parentOrgCode; // 项目部所属组织编码
    private String parentOrgName; // 项目部所属组织名称
    private Long projectId; // 项目id
    private String projectCode; // 项目编码
    private String projectName; // 项目名称
    private String sourceType; // 来源
    @JsonFormat(shape = JsonFormat.Shape.STRING, pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private Date fillDate; // 填报日期
    private String week; // 星期
    private String weather; // 天气
    private String windPower; // 风力
    private String temperature; // 温度
    private String humidity; // 湿度
    private Long airQuality; // 空气质量
    private String airQualityName; //空气质量名称
    private Long commitUserId; // 提交人id
    private String commitUserCode; // 提交人账号
    private String commitUserName; // 提交人名称
    @JsonFormat(shape = JsonFormat.Shape.STRING, pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private Date commitDate; // 提交日期
    private Long projectLogId; // 项目日志id

    private String provinceName; //省
    private String cityName; //市
    private String districtName; //区

    private List<LedgerDetailVO> ledgerDetailList = new ArrayList<>(); // 日志台账-施工内容（施工员）
    private List<LedgerScheduleVO> ledgerScheduleList = new ArrayList<>(); // 日志台账-进度情况（施工员）
    private List<LedgerTypeVO> ledgerTypeList = new ArrayList<>(); // 日志台账-施工组织设计、方案、交底、变更情况（技术负责人）
    private List<LedgerQualityVO> ledgerQualityList = new ArrayList<>(); // 日志台账-工程质量检查、验收情况（质检员）
    private List<LedgerSafetyVO> ledgerSafetyList = new ArrayList<>(); // 日志台账-安全活动情况（安全员）
    private List<LedgerMaterialVO> ledgerMaterialList = new ArrayList<>(); // 日志台账-材料进出场情况（材料员）
    private List<LedgerEquipmentVO> ledgerEquipmentList = new ArrayList<>(); // 日志台账-设备进出场情况（设备管理员）
    private List<LedgerExamineVO> ledgerExamineList = new ArrayList<>(); // 日志台账-检验试验情况（取样员）
    private List<LedgerInformationVO> ledgerInformationList = new ArrayList<>(); // 日志台账-工程资料归档及会议情况（资料员）
    private List<LedgerOtherVO> ledgerOtherList = new ArrayList<>(); // 日志台账-其他情况

    private String ledgerScheduleDescription;
    private String ledgerTypeDescription;
    private String ledgerQualityDescription;
    private String ledgerSafetyDescription;
    private String ledgerMaterialDescription;
    private String ledgerEquipmentDescription;
    private String ledgerExamineDescription;
    private String ledgerInformationDescription;
    private String ledgerOtherDescription;

    public String getProvinceName() {
        return provinceName;
    }

    public void setProvinceName(String provinceName) {
        this.provinceName = provinceName;
    }

    public String getCityName() {
        return cityName;
    }

    public void setCityName(String cityName) {
        this.cityName = cityName;
    }

    public String getDistrictName() {
        return districtName;
    }

    public void setDistrictName(String districtName) {
        this.districtName = districtName;
    }

    public String getAirQualityName() {
        return airQualityName;
    }

    public void setAirQualityName(String airQualityName) {
        this.airQualityName = airQualityName;
    }

    public Date getEffectiveDate() {
        return effectiveDate;
    }

    public void setEffectiveDate(Date effectiveDate) {
        this.effectiveDate = effectiveDate;
    }
    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    public String getBillName() {
        return billName;
    }

    public void setBillName(String billName) {
        this.billName = billName;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    public String getBillStateName() {
        return billStateName;
    }

    public void setBillStateName(String billStateName) {
        this.billStateName = billStateName;
    }
    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getOrgCode() {
        return orgCode;
    }

    public void setOrgCode(String orgCode) {
        this.orgCode = orgCode;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    public Long getParentOrgId() {
        return parentOrgId;
    }

    public void setParentOrgId(Long parentOrgId) {
        this.parentOrgId = parentOrgId;
    }
    public String getParentOrgCode() {
        return parentOrgCode;
    }

    public void setParentOrgCode(String parentOrgCode) {
        this.parentOrgCode = parentOrgCode;
    }
    public String getParentOrgName() {
        return parentOrgName;
    }

    public void setParentOrgName(String parentOrgName) {
        this.parentOrgName = parentOrgName;
    }
    public Long getProjectId() {
        return projectId;
    }

    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }
    public String getProjectCode() {
        return projectCode;
    }

    public void setProjectCode(String projectCode) {
        this.projectCode = projectCode;
    }
    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }

    public String getSourceType() {
        return sourceType;
    }

    public void setSourceType(String sourceType) {
        this.sourceType = sourceType;
    }

    public Date getFillDate() {
        return fillDate;
    }

    public void setFillDate(Date fillDate) {
        this.fillDate = fillDate;
    }
    public String getWeek() {
        return week;
    }

    public void setWeek(String week) {
        this.week = week;
    }
    public String getWeather() {
        return weather;
    }

    public void setWeather(String weather) {
        this.weather = weather;
    }

    public String getWindPower() {
        return windPower;
    }

    public void setWindPower(String windPower) {
        this.windPower = windPower;
    }

    public String getTemperature() {
        return temperature;
    }

    public void setTemperature(String temperature) {
        this.temperature = temperature;
    }

    public String getHumidity() {
        return humidity;
    }

    public void setHumidity(String humidity) {
        this.humidity = humidity;
    }
    public Long getCommitUserId() {
        return commitUserId;
    }

    public void setCommitUserId(Long commitUserId) {
        this.commitUserId = commitUserId;
    }
    public String getCommitUserCode() {
        return commitUserCode;
    }

    public void setCommitUserCode(String commitUserCode) {
        this.commitUserCode = commitUserCode;
    }
    public String getCommitUserName() {
        return commitUserName;
    }

    public void setCommitUserName(String commitUserName) {
        this.commitUserName = commitUserName;
    }
    public Date getCommitDate() {
        return commitDate;
    }

    public void setCommitDate(Date commitDate) {
        this.commitDate = commitDate;
    }
    public Long getProjectLogId() {
        return projectLogId;
    }

    public void setProjectLogId(Long projectLogId) {
        this.projectLogId = projectLogId;
    }

     public List<LedgerDetailVO> getLedgerDetailList() {
        return ledgerDetailList;
     }

     public void setLedgerDetailList(List<LedgerDetailVO> ledgerDetailList) {
        this.ledgerDetailList = ledgerDetailList;
     }
     public List<LedgerScheduleVO> getLedgerScheduleList() {
        return ledgerScheduleList;
     }

     public void setLedgerScheduleList(List<LedgerScheduleVO> ledgerScheduleList) {
        this.ledgerScheduleList = ledgerScheduleList;
     }
     public List<LedgerTypeVO> getLedgerTypeList() {
        return ledgerTypeList;
     }

     public void setLedgerTypeList(List<LedgerTypeVO> ledgerTypeList) {
        this.ledgerTypeList = ledgerTypeList;
     }
     public List<LedgerQualityVO> getLedgerQualityList() {
        return ledgerQualityList;
     }

     public void setLedgerQualityList(List<LedgerQualityVO> ledgerQualityList) {
        this.ledgerQualityList = ledgerQualityList;
     }
     public List<LedgerSafetyVO> getLedgerSafetyList() {
        return ledgerSafetyList;
     }

     public void setLedgerSafetyList(List<LedgerSafetyVO> ledgerSafetyList) {
        this.ledgerSafetyList = ledgerSafetyList;
     }
     public List<LedgerMaterialVO> getLedgerMaterialList() {
        return ledgerMaterialList;
     }

     public void setLedgerMaterialList(List<LedgerMaterialVO> ledgerMaterialList) {
        this.ledgerMaterialList = ledgerMaterialList;
     }
     public List<LedgerEquipmentVO> getLedgerEquipmentList() {
        return ledgerEquipmentList;
     }

     public void setLedgerEquipmentList(List<LedgerEquipmentVO> ledgerEquipmentList) {
        this.ledgerEquipmentList = ledgerEquipmentList;
     }
     public List<LedgerExamineVO> getLedgerExamineList() {
        return ledgerExamineList;
     }

     public void setLedgerExamineList(List<LedgerExamineVO> ledgerExamineList) {
        this.ledgerExamineList = ledgerExamineList;
     }
     public List<LedgerInformationVO> getLedgerInformationList() {
        return ledgerInformationList;
     }

     public void setLedgerInformationList(List<LedgerInformationVO> ledgerInformationList) {
        this.ledgerInformationList = ledgerInformationList;
     }
     public List<LedgerOtherVO> getLedgerOtherList() {
        return ledgerOtherList;
     }

     public void setLedgerOtherList(List<LedgerOtherVO> ledgerOtherList) {
        this.ledgerOtherList = ledgerOtherList;
     }
    @ReferSerialTransfer(referCode="support-defdoc")
    public Long getAirQuality() {
        return airQuality;
    }

    @ReferDeserialTransfer
    public void setAirQuality(Long airQuality) {
        this.airQuality = airQuality;
    }


    public String getLedgerScheduleDescription() {
        return ledgerScheduleDescription;
    }

    public void setLedgerScheduleDescription(String ledgerScheduleDescription) {
        this.ledgerScheduleDescription = ledgerScheduleDescription;
    }

    public String getLedgerTypeDescription() {
        return ledgerTypeDescription;
    }

    public void setLedgerTypeDescription(String ledgerTypeDescription) {
        this.ledgerTypeDescription = ledgerTypeDescription;
    }

    public String getLedgerQualityDescription() {
        return ledgerQualityDescription;
    }

    public void setLedgerQualityDescription(String ledgerQualityDescription) {
        this.ledgerQualityDescription = ledgerQualityDescription;
    }

    public String getLedgerSafetyDescription() {
        return ledgerSafetyDescription;
    }

    public void setLedgerSafetyDescription(String ledgerSafetyDescription) {
        this.ledgerSafetyDescription = ledgerSafetyDescription;
    }

    public String getLedgerMaterialDescription() {
        return ledgerMaterialDescription;
    }

    public void setLedgerMaterialDescription(String ledgerMaterialDescription) {
        this.ledgerMaterialDescription = ledgerMaterialDescription;
    }

    public String getLedgerEquipmentDescription() {
        return ledgerEquipmentDescription;
    }

    public void setLedgerEquipmentDescription(String ledgerEquipmentDescription) {
        this.ledgerEquipmentDescription = ledgerEquipmentDescription;
    }

    public String getLedgerExamineDescription() {
        return ledgerExamineDescription;
    }

    public void setLedgerExamineDescription(String ledgerExamineDescription) {
        this.ledgerExamineDescription = ledgerExamineDescription;
    }

    public String getLedgerInformationDescription() {
        return ledgerInformationDescription;
    }

    public void setLedgerInformationDescription(String ledgerInformationDescription) {
        this.ledgerInformationDescription = ledgerInformationDescription;
    }

    public String getLedgerOtherDescription() {
        return ledgerOtherDescription;
    }

    public void setLedgerOtherDescription(String ledgerOtherDescription) {
        this.ledgerOtherDescription = ledgerOtherDescription;
    }
}
